// Generated by gmmproc 2.88.0 -- DO NOT MODIFY!
#ifndef _GTKMM_SYMBOLICPAINTABLE_H
#define _GTKMM_SYMBOLICPAINTABLE_H

#include <gtkmmconfig.h>


#include <glibmm/ustring.h>
#include <sigc++/sigc++.h>

/* Copyright (C) 2023 The gtkmm Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */


#include <glibmm/interface.h>
#include <gdkmm/rgba.h>
#include <gdkmm/snapshot.h>


#ifndef DOXYGEN_SHOULD_SKIP_THIS
extern "C"
{
typedef struct _GtkSymbolicPaintableInterface GtkSymbolicPaintableInterface;
}
#endif /* DOXYGEN_SHOULD_SKIP_THIS */

#ifndef DOXYGEN_SHOULD_SKIP_THIS
using GtkSymbolicPaintable = struct _GtkSymbolicPaintable;
using GtkSymbolicPaintableClass = struct _GtkSymbolicPaintableClass;
#endif /* DOXYGEN_SHOULD_SKIP_THIS */


#ifndef DOXYGEN_SHOULD_SKIP_THIS
namespace Gtk
{ class GTKMM_API SymbolicPaintable_Class; } // namespace Gtk
#endif // DOXYGEN_SHOULD_SKIP_THIS

namespace Gtk
{

/** An interface that supports symbolic colors in paintables.
 *
 * Gdk::Paintable%s implementing the interface will have the
 * snapshot_symbolic_vfunc() function called and have the colors for drawing
 * symbolic icons passed. At least 5 colors are guaranteed to be passed every time.
 * These 5 colors are the foreground color, and the colors to use for errors,
 * warnings and success information in that order, followed by the system
 * accent color.
 *
 * The system accent color has been added in GTK 4.22.
 * More colors may be added in the future.
 *
 * @newin{4,12}
 */

class GTKMM_API SymbolicPaintable : public Glib::Interface
{
  
#ifndef DOXYGEN_SHOULD_SKIP_THIS

public:
  using CppObjectType = SymbolicPaintable;
  using CppClassType = SymbolicPaintable_Class;
  using BaseObjectType = GtkSymbolicPaintable;
  using BaseClassType = GtkSymbolicPaintableInterface;

  // noncopyable
  SymbolicPaintable(const SymbolicPaintable&) = delete;
  SymbolicPaintable& operator=(const SymbolicPaintable&) = delete;

private:
  friend class SymbolicPaintable_Class;
  static CppClassType symbolicpaintable_class_;

#endif /* DOXYGEN_SHOULD_SKIP_THIS */
protected:
  /**
   * You should derive from this class to use it.
   */
  SymbolicPaintable();

#ifndef DOXYGEN_SHOULD_SKIP_THIS
  /** Called by constructors of derived classes. Provide the result of
   * the Class init() function to ensure that it is properly
   * initialized.
   *
   * @param interface_class The Class object for the derived type.
   */
  explicit SymbolicPaintable(const Glib::Interface_Class& interface_class);

public:
  // This is public so that C++ wrapper instances can be
  // created for C instances of unwrapped types.
  // For instance, if an unexpected C type implements the C interface.
  explicit SymbolicPaintable(GtkSymbolicPaintable* castitem);

protected:
#endif /* DOXYGEN_SHOULD_SKIP_THIS */

public:

  SymbolicPaintable(SymbolicPaintable&& src) noexcept;
  SymbolicPaintable& operator=(SymbolicPaintable&& src) noexcept;

  ~SymbolicPaintable() noexcept override;

  static void add_interface(GType gtype_implementer);

  /** Get the GType for this class, for use with the underlying GObject type system.
   */
  static GType get_type()      G_GNUC_CONST;

#ifndef DOXYGEN_SHOULD_SKIP_THIS
  static GType get_base_type() G_GNUC_CONST;
#endif

  ///Provides access to the underlying C GObject.
  GtkSymbolicPaintable*       gobj()       { return reinterpret_cast<GtkSymbolicPaintable*>(gobject_); }

  ///Provides access to the underlying C GObject.
  const GtkSymbolicPaintable* gobj() const { return reinterpret_cast<GtkSymbolicPaintable*>(gobject_); }

private:


public:
  /** Snapshots the paintable with the given colors.
   *
   * If less than 4 colors are provided, GTK will pad the vector with
   * default colors.
   *
   * @newin{4,12}
   *
   * @param snapshot A Gdk::Snapshot to snapshot to.
   * @param width Width to snapshot in.
   * @param height Height to snapshot in.
   * @param colors A vector of colors.
   */
  void snapshot_symbolic(const Glib::RefPtr<Gdk::Snapshot>& snapshot,
    double width, double height, const std::vector<Gdk::RGBA>& colors);
  

  /** Snapshots the paintable with the given colors and weight.
   *
   * If less than 5 colors are provided, GTK will pad the array with default colors.
   *
   * @newin{4,22}
   *
   * @param snapshot A `Gdk::Snapshot` to snapshot to.
   * @param width Width to snapshot in.
   * @param height Height to snapshot in.
   * @param colors A vector of colors.
   * @param weight The font weight to use (from 1 to 1000, with default 400).
   */
  void snapshot_with_weight(const Glib::RefPtr<Gdk::Snapshot>& snapshot,
    double width, double height, const std::vector<Gdk::RGBA>& colors, double weight);
  

protected:


// TODO: When we can break ABI, add snapshot_with_weight_vfunc().


public:

public:
  //C++ methods used to invoke GTK+ virtual functions:

protected:
  //GTK+ Virtual Functions (override these to change behaviour):
virtual void snapshot_symbolic_vfunc(const Glib::RefPtr<Gdk::Snapshot>& snapshot, double width, double height, const std::vector<Gdk::RGBA>& colors);


  //Default Signal Handlers::


};

} // namespace Gtk


namespace Glib
{
  /** A Glib::wrap() method for this object.
   *
   * @param object The C instance.
   * @param take_copy False if the result should take ownership of the C instance. True if it should take a new copy or ref.
   * @result A C++ instance that wraps this C instance.
   *
   * @relates Gtk::SymbolicPaintable
   */
  GTKMM_API
  Glib::RefPtr<Gtk::SymbolicPaintable> wrap(GtkSymbolicPaintable* object, bool take_copy = false);

} // namespace Glib


#endif /* _GTKMM_SYMBOLICPAINTABLE_H */

