// Generated by gmmproc 2.88.0 -- DO NOT MODIFY!
#ifndef _GTKMM_ACCESSIBLEHYPERTEXT_H
#define _GTKMM_ACCESSIBLEHYPERTEXT_H

#include <gtkmmconfig.h>


#include <glibmm/ustring.h>
#include <sigc++/sigc++.h>

/* Copyright (C) 2025 The gtkmm Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */


#include <glibmm/interface.h>


#ifndef DOXYGEN_SHOULD_SKIP_THIS
extern "C"
{
typedef struct _GtkAccessibleHypertextInterface GtkAccessibleHypertextInterface;
}
#endif /* DOXYGEN_SHOULD_SKIP_THIS */

#ifndef DOXYGEN_SHOULD_SKIP_THIS
using GtkAccessibleHypertext = struct _GtkAccessibleHypertext;
using GtkAccessibleHypertextClass = struct _GtkAccessibleHypertextClass;
#endif /* DOXYGEN_SHOULD_SKIP_THIS */


#ifndef DOXYGEN_SHOULD_SKIP_THIS
namespace Gtk
{ class GTKMM_API AccessibleHypertext_Class; } // namespace Gtk
#endif // DOXYGEN_SHOULD_SKIP_THIS

namespace Gtk
{
class GTKMM_API AccessibleHyperlink;

/** An interface for accessible objects containing links.
 *
 * The %Gtk::AccessibleHypertext interface is meant to be implemented by accessible
 * objects that contain links. Those links don't necessarily have to be part
 * of text, they can be associated with images and other things.
 *
 * @newin{4,22}
 */

class GTKMM_API AccessibleHypertext : public Glib::Interface
{
  
#ifndef DOXYGEN_SHOULD_SKIP_THIS

public:
  using CppObjectType = AccessibleHypertext;
  using CppClassType = AccessibleHypertext_Class;
  using BaseObjectType = GtkAccessibleHypertext;
  using BaseClassType = GtkAccessibleHypertextInterface;

  // noncopyable
  AccessibleHypertext(const AccessibleHypertext&) = delete;
  AccessibleHypertext& operator=(const AccessibleHypertext&) = delete;

private:
  friend class AccessibleHypertext_Class;
  static CppClassType accessiblehypertext_class_;

#endif /* DOXYGEN_SHOULD_SKIP_THIS */
protected:
  /**
   * You should derive from this class to use it.
   */
  AccessibleHypertext();

#ifndef DOXYGEN_SHOULD_SKIP_THIS
  /** Called by constructors of derived classes. Provide the result of
   * the Class init() function to ensure that it is properly
   * initialized.
   *
   * @param interface_class The Class object for the derived type.
   */
  explicit AccessibleHypertext(const Glib::Interface_Class& interface_class);

public:
  // This is public so that C++ wrapper instances can be
  // created for C instances of unwrapped types.
  // For instance, if an unexpected C type implements the C interface.
  explicit AccessibleHypertext(GtkAccessibleHypertext* castitem);

protected:
#endif /* DOXYGEN_SHOULD_SKIP_THIS */

public:

  AccessibleHypertext(AccessibleHypertext&& src) noexcept;
  AccessibleHypertext& operator=(AccessibleHypertext&& src) noexcept;

  ~AccessibleHypertext() noexcept override;

  static void add_interface(GType gtype_implementer);

  /** Get the GType for this class, for use with the underlying GObject type system.
   */
  static GType get_type()      G_GNUC_CONST;

#ifndef DOXYGEN_SHOULD_SKIP_THIS
  static GType get_base_type() G_GNUC_CONST;
#endif

  ///Provides access to the underlying C GObject.
  GtkAccessibleHypertext*       gobj()       { return reinterpret_cast<GtkAccessibleHypertext*>(gobject_); }

  ///Provides access to the underlying C GObject.
  const GtkAccessibleHypertext* gobj() const { return reinterpret_cast<GtkAccessibleHypertext*>(gobject_); }

private:


public:

protected:
  /** Retrieve the number of links in the accessible object.
   *
   * @returns The number of links.
   * @newin{4,22}
   */
    virtual unsigned int get_n_links_vfunc() const;


  /** Retrieve the n-th link in the accessible object.
   *
   * @param index Must be less than the number of links.
   * @returns The link.
   *
   * @newin{4,22}
   */
    virtual Glib::RefPtr<AccessibleHyperlink> get_link_vfunc(unsigned int index);


  /** Retrieves the index of the link at the given character offset.
   *
   * Note that this method will return `G_MAXUINT` if the object
   * does not contain text.
   *
   * @param offset The character offset.
   * @returns Index of the link at the given character offset, or
   *   `G_MAXUINT` if there is no link.
   *
   * @newin{4,22}
   */
    virtual unsigned int get_link_at_vfunc(unsigned int offset) const;


public:

public:
  //C++ methods used to invoke GTK+ virtual functions:

protected:
  //GTK+ Virtual Functions (override these to change behaviour):

  //Default Signal Handlers::


};

} // namespace Gtk


namespace Glib
{
  /** A Glib::wrap() method for this object.
   *
   * @param object The C instance.
   * @param take_copy False if the result should take ownership of the C instance. True if it should take a new copy or ref.
   * @result A C++ instance that wraps this C instance.
   *
   * @relates Gtk::AccessibleHypertext
   */
  GTKMM_API
  Glib::RefPtr<Gtk::AccessibleHypertext> wrap(GtkAccessibleHypertext* object, bool take_copy = false);

} // namespace Glib


#endif /* _GTKMM_ACCESSIBLEHYPERTEXT_H */

