// Generated by gmmproc 2.88.0 -- DO NOT MODIFY!
#ifndef _GTKMM_MULTIFILTER_P_H
#define _GTKMM_MULTIFILTER_P_H


#include <gtkmm/private/filter_p.h>

#include <glibmm/class.h>

namespace Gtk
{

class GTKMM_API MultiFilter_Class : public Glib::Class
{
public:
#ifndef DOXYGEN_SHOULD_SKIP_THIS
  using CppObjectType = MultiFilter;
  using BaseObjectType = GtkMultiFilter;
  using BaseClassType = GtkMultiFilterClass;
  using CppClassParent = Gtk::Filter_Class;
  using BaseClassParent = GtkFilterClass;

  friend class MultiFilter;
#endif /* DOXYGEN_SHOULD_SKIP_THIS */

  const Glib::Class& init();


  static void class_init_function(void* g_class, void* class_data);

  static Glib::ObjectBase* wrap_new(GObject*);

protected:

  //Callbacks (default signal handlers):
  //These will call the *_impl member methods, which will then call the existing default signal callbacks, if any.
  //You could prevent the original default signal handlers being called by overriding the *_impl method.

  //Callbacks (virtual functions):
};


} // namespace Gtk


#include <glibmm/class.h>

namespace Gtk
{

class GTKMM_API AnyFilter_Class : public Glib::Class
{
public:
#ifndef DOXYGEN_SHOULD_SKIP_THIS
  using CppObjectType = AnyFilter;
  using BaseObjectType = GtkAnyFilter;
  using BaseClassType = GtkAnyFilterClass;
  using CppClassParent = Gtk::MultiFilter_Class;
  using BaseClassParent = GtkMultiFilterClass;

  friend class AnyFilter;
#endif /* DOXYGEN_SHOULD_SKIP_THIS */

  const Glib::Class& init();


  static void class_init_function(void* g_class, void* class_data);

  static Glib::ObjectBase* wrap_new(GObject*);

protected:

  //Callbacks (default signal handlers):
  //These will call the *_impl member methods, which will then call the existing default signal callbacks, if any.
  //You could prevent the original default signal handlers being called by overriding the *_impl method.

  //Callbacks (virtual functions):
};


} // namespace Gtk


#include <glibmm/class.h>

namespace Gtk
{

class GTKMM_API EveryFilter_Class : public Glib::Class
{
public:
#ifndef DOXYGEN_SHOULD_SKIP_THIS
  using CppObjectType = EveryFilter;
  using BaseObjectType = GtkEveryFilter;
  using BaseClassType = GtkEveryFilterClass;
  using CppClassParent = Gtk::MultiFilter_Class;
  using BaseClassParent = GtkMultiFilterClass;

  friend class EveryFilter;
#endif /* DOXYGEN_SHOULD_SKIP_THIS */

  const Glib::Class& init();


  static void class_init_function(void* g_class, void* class_data);

  static Glib::ObjectBase* wrap_new(GObject*);

protected:

  //Callbacks (default signal handlers):
  //These will call the *_impl member methods, which will then call the existing default signal callbacks, if any.
  //You could prevent the original default signal handlers being called by overriding the *_impl method.

  //Callbacks (virtual functions):
};


} // namespace Gtk


#endif /* _GTKMM_MULTIFILTER_P_H */

