// Generated by gmmproc 2.88.0 -- DO NOT MODIFY!
#ifndef _GTKMM_FIXEDLAYOUTCHILD_H
#define _GTKMM_FIXEDLAYOUTCHILD_H


#include <glibmm/ustring.h>
#include <sigc++/sigc++.h>

/* Copyright (C) 2025 The gtkmm Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */

#include <gtkmm/layoutchild.h>
#include <gskmm/transform.h>
#include <gtk/gtk.h>


#ifndef DOXYGEN_SHOULD_SKIP_THIS
#endif /* DOXYGEN_SHOULD_SKIP_THIS */


#ifndef DOXYGEN_SHOULD_SKIP_THIS
namespace Gtk
{ class GTKMM_API FixedLayoutChild_Class; } // namespace Gtk
#endif //DOXYGEN_SHOULD_SKIP_THIS

namespace Gtk
{
/** Layout properties for children of Gtk::FixedLayout.
 *
 * %Gtk::FixedLayoutChild instances are created by Gtk::FixedLayout.
 * To create or get a %Gtk::FixedLayoutChild instance, call Gtk::LayoutManager::get_layout_child()
 * from a Gtk::FixedLayout instance.
 * @code
 * Glib::RefPtr<Gtk::LayoutChild> layout_child =
 *   fixed_layout->get_layout_child(child);
 * Glib::RefPtr<Gtk::FixedLayoutChild> fixed_layout_child =
 *   std::dynamic_pointer_cast<Gtk::FixedLayoutChild>(layout_child);
 * if (fixed_layout_child)
 *   // Do something with fixed_layout_child
 * @endcode
 *
 * @newin{4,20}
 */

class GTKMM_API FixedLayoutChild : public LayoutChild
{
  
#ifndef DOXYGEN_SHOULD_SKIP_THIS

public:
  using CppObjectType = FixedLayoutChild;
  using CppClassType = FixedLayoutChild_Class;
  using BaseObjectType = GtkFixedLayoutChild;
  using BaseClassType = GtkFixedLayoutChildClass;

  // noncopyable
  FixedLayoutChild(const FixedLayoutChild&) = delete;
  FixedLayoutChild& operator=(const FixedLayoutChild&) = delete;

private:  friend class FixedLayoutChild_Class;
  static CppClassType fixedlayoutchild_class_;

protected:
  explicit FixedLayoutChild(const Glib::ConstructParams& construct_params);
  explicit FixedLayoutChild(GtkFixedLayoutChild* castitem);

#endif /* DOXYGEN_SHOULD_SKIP_THIS */

public:

  FixedLayoutChild(FixedLayoutChild&& src) noexcept;
  FixedLayoutChild& operator=(FixedLayoutChild&& src) noexcept;

  ~FixedLayoutChild() noexcept override;

  /** Get the GType for this class, for use with the underlying GObject type system.
   */
  static GType get_type()      G_GNUC_CONST;

#ifndef DOXYGEN_SHOULD_SKIP_THIS


  static GType get_base_type() G_GNUC_CONST;
#endif

  ///Provides access to the underlying C GObject.
  GtkFixedLayoutChild*       gobj()       { return reinterpret_cast<GtkFixedLayoutChild*>(gobject_); }

  ///Provides access to the underlying C GObject.
  const GtkFixedLayoutChild* gobj() const { return reinterpret_cast<GtkFixedLayoutChild*>(gobject_); }

  ///Provides access to the underlying C instance. The caller is responsible for unrefing it. Use when directly setting fields in structs.
  GtkFixedLayoutChild* gobj_copy();

private:

     
protected:
  /** Default constructor.
   *
   * There is no create() method that corresponds to this constructor.
   * To create or get a %Gtk::FixedLayoutChild instance, call Gtk::LayoutManager::get_layout_child()
   * from a Gtk::FixedLayout instance.
   */
  FixedLayoutChild();

public:
  // No create() method. Use Gtk::LayoutManager::get_layout_child().

  // A Gsk::Transform is immutable. There's no significant difference between
  // a Gsk::Transform and a const Gsk::Transform.
  
  /** Sets the transformation of the child of a `Gtk::FixedLayout`.
   * 
   * @param transform A `Gsk::Transform`.
   */
  void set_transform(const Glib::RefPtr<const Gsk::Transform>& transform);
  
  /** Retrieves the transformation of the child.
   * 
   * @return A `Gsk::Transform`.
   */
  Glib::RefPtr<Gsk::Transform> get_transform() const;

  /** The transform of the child.
   *
   * @return A PropertyProxy that allows you to get or set the value of the property,
   * or receive notification when the value of the property changes.
   */
  Glib::PropertyProxy< Glib::RefPtr<Gsk::Transform> > property_transform() ;

/** The transform of the child.
   *
   * @return A PropertyProxy_ReadOnly that allows you to get the value of the property,
   * or receive notification when the value of the property changes.
   */
  Glib::PropertyProxy_ReadOnly< Glib::RefPtr<Gsk::Transform> > property_transform() const;


  // There are no signals or vfuncs.


public:

public:
  //C++ methods used to invoke GTK+ virtual functions:

protected:
  //GTK+ Virtual Functions (override these to change behaviour):

  //Default Signal Handlers::


};

} // namespace Gtk


namespace Glib
{
  /** A Glib::wrap() method for this object.
   *
   * @param object The C instance.
   * @param take_copy False if the result should take ownership of the C instance. True if it should take a new copy or ref.
   * @result A C++ instance that wraps this C instance.
   *
   * @relates Gtk::FixedLayoutChild
   */
  GTKMM_API
  Glib::RefPtr<Gtk::FixedLayoutChild> wrap(GtkFixedLayoutChild* object, bool take_copy = false);
}


#endif /* _GTKMM_FIXEDLAYOUTCHILD_H */

