// Generated by gmmproc 2.88.0 -- DO NOT MODIFY!
#ifndef _GTKMM_ACCESSIBLEHYPERLINK_H
#define _GTKMM_ACCESSIBLEHYPERLINK_H


#include <glibmm/ustring.h>
#include <sigc++/sigc++.h>

/* Copyright (C) 2025 The gtkmm Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */

#include <glibmm/object.h>
#include <glibmm/ustring.h>
#include <gtkmm/accessible.h>
#include <gtkmm/accessiblehypertext.h>
#include <gtk/gtk.h> // for GtkAccessibleTextRange


#ifndef DOXYGEN_SHOULD_SKIP_THIS
#endif /* DOXYGEN_SHOULD_SKIP_THIS */


#ifndef DOXYGEN_SHOULD_SKIP_THIS
namespace Gtk
{ class GTKMM_API AccessibleHyperlink_Class; } // namespace Gtk
#endif //DOXYGEN_SHOULD_SKIP_THIS

namespace Gtk
{
/** Represents a link (a uri).
 *
 * A widget that contains one or more links should implement
 * the Gtk::AccessibleHypertext interface and return
 * %Gtk::AccessibleHyperlink objects for each of the links.
 *
 * @newin{4,22}
 */

class GTKMM_API AccessibleHyperlink : public Glib::Object, public Accessible
{
  
#ifndef DOXYGEN_SHOULD_SKIP_THIS

public:
  using CppObjectType = AccessibleHyperlink;
  using CppClassType = AccessibleHyperlink_Class;
  using BaseObjectType = GtkAccessibleHyperlink;
  using BaseClassType = GtkAccessibleHyperlinkClass;

  // noncopyable
  AccessibleHyperlink(const AccessibleHyperlink&) = delete;
  AccessibleHyperlink& operator=(const AccessibleHyperlink&) = delete;

private:  friend class AccessibleHyperlink_Class;
  static CppClassType accessiblehyperlink_class_;

protected:
  explicit AccessibleHyperlink(const Glib::ConstructParams& construct_params);
  explicit AccessibleHyperlink(GtkAccessibleHyperlink* castitem);

#endif /* DOXYGEN_SHOULD_SKIP_THIS */

public:

  AccessibleHyperlink(AccessibleHyperlink&& src) noexcept;
  AccessibleHyperlink& operator=(AccessibleHyperlink&& src) noexcept;

  ~AccessibleHyperlink() noexcept override;

  /** Get the GType for this class, for use with the underlying GObject type system.
   */
  static GType get_type()      G_GNUC_CONST;

#ifndef DOXYGEN_SHOULD_SKIP_THIS


  static GType get_base_type() G_GNUC_CONST;
#endif

  ///Provides access to the underlying C GObject.
  GtkAccessibleHyperlink*       gobj()       { return reinterpret_cast<GtkAccessibleHyperlink*>(gobject_); }

  ///Provides access to the underlying C GObject.
  const GtkAccessibleHyperlink* gobj() const { return reinterpret_cast<GtkAccessibleHyperlink*>(gobject_); }

  ///Provides access to the underlying C instance. The caller is responsible for unrefing it. Use when directly setting fields in structs.
  GtkAccessibleHyperlink* gobj_copy();

private:

  
public:
  // gtk_accessible_hyperlink_new() does more than call g_object_new().
  // GtkAccessibleHyperlink has no properties.
  
  /** Creates an accessible object that represents a hyperlink.
   * 
   * This is meant to be used with an implementation of the
   * Gtk::AccessibleHypertext interface.
   * 
   * @newin{4,22}
   * 
   * @param parent The parent.
   * @param index The index of this link in the parent.
   * @param uri The uri.
   * @param bounds The text range that the link occupies (or 0, 0).
   */
  static Glib::RefPtr<AccessibleHyperlink> create(const Glib::RefPtr<AccessibleHypertext>& parent, unsigned int index, const Glib::ustring& uri, const GtkAccessibleTextRange& bounds);

  // There are no properties, signals or vfuncs.


public:

public:
  //C++ methods used to invoke GTK+ virtual functions:

protected:
  //GTK+ Virtual Functions (override these to change behaviour):

  //Default Signal Handlers::


};

} // namespace Gtk


namespace Glib
{
  /** A Glib::wrap() method for this object.
   *
   * @param object The C instance.
   * @param take_copy False if the result should take ownership of the C instance. True if it should take a new copy or ref.
   * @result A C++ instance that wraps this C instance.
   *
   * @relates Gtk::AccessibleHyperlink
   */
  GTKMM_API
  Glib::RefPtr<Gtk::AccessibleHyperlink> wrap(GtkAccessibleHyperlink* object, bool take_copy = false);
}


#endif /* _GTKMM_ACCESSIBLEHYPERLINK_H */

