// Generated by gmmproc 2.88.0 -- DO NOT MODIFY!
#ifndef _GTKMM_ICONPAINTABLE_H
#define _GTKMM_ICONPAINTABLE_H

#include <gtkmmconfig.h>


#include <glibmm/ustring.h>
#include <sigc++/sigc++.h>

/* Copyright (C) 2003 The gtkmm Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see <https://www.gnu.org/licenses/>.
 */


#include <glibmm/object.h>
#include <gdkmm/paintable.h>
#include <giomm/file.h>
#include <gtk/gtk.h>


#ifndef DOXYGEN_SHOULD_SKIP_THIS
#endif /* DOXYGEN_SHOULD_SKIP_THIS */


#ifndef DOXYGEN_SHOULD_SKIP_THIS
namespace Gtk
{ class GTKMM_API IconPaintable_Class; } // namespace Gtk
#endif //DOXYGEN_SHOULD_SKIP_THIS

namespace Gtk
{

//TODO: Derive from (and implement) SymbolicPaintable when we can break ABI.
/** An icon, used with Gtk::IconTheme.
 */

class GTKMM_API IconPaintable : public Glib::Object, public Gdk::Paintable
{
  
#ifndef DOXYGEN_SHOULD_SKIP_THIS

public:
  using CppObjectType = IconPaintable;
  using CppClassType = IconPaintable_Class;
  using BaseObjectType = GtkIconPaintable;
  using BaseClassType = GtkIconPaintableClass;

  // noncopyable
  IconPaintable(const IconPaintable&) = delete;
  IconPaintable& operator=(const IconPaintable&) = delete;

private:  friend class IconPaintable_Class;
  static CppClassType iconpaintable_class_;

protected:
  explicit IconPaintable(const Glib::ConstructParams& construct_params);
  explicit IconPaintable(GtkIconPaintable* castitem);

#endif /* DOXYGEN_SHOULD_SKIP_THIS */

public:

  IconPaintable(IconPaintable&& src) noexcept;
  IconPaintable& operator=(IconPaintable&& src) noexcept;

  ~IconPaintable() noexcept override;

  /** Get the GType for this class, for use with the underlying GObject type system.
   */
  static GType get_type()      G_GNUC_CONST;

#ifndef DOXYGEN_SHOULD_SKIP_THIS


  static GType get_base_type() G_GNUC_CONST;
#endif

  ///Provides access to the underlying C GObject.
  GtkIconPaintable*       gobj()       { return reinterpret_cast<GtkIconPaintable*>(gobject_); }

  ///Provides access to the underlying C GObject.
  const GtkIconPaintable* gobj() const { return reinterpret_cast<GtkIconPaintable*>(gobject_); }

  ///Provides access to the underlying C instance. The caller is responsible for unrefing it. Use when directly setting fields in structs.
  GtkIconPaintable* gobj_copy();

private:

  
public:
  // gtk_icon_paintable_new_for_file() does more than call g_object_new().
  
  /** Creates a `Gtk::IconPaintable` for a file with a given size and scale.
   * 
   * The icon can then be rendered by using it as a `Gdk::Paintable`.
   * 
   * @param file A `Gio::File`.
   * @param size Desired icon size, in application pixels.
   * @param scale The desired scale.
   * @return A `Gtk::IconPaintable` containing
   * for the icon. Unref with Glib::object_unref().
   */
  static Glib::RefPtr<IconPaintable> create(const Glib::RefPtr<Gio::File>& file, int size, int scale =  1);

  // The const get_file() can return a non-const Gio::File.
  // gtk_icon_paintable_get_file() returns a newly created GFile.
  
  /** Gets the `Gio::File` that was used to load the icon.
   * 
   * @return The `Gio::File` for the icon.
   */
  Glib::RefPtr<Gio::File> get_file() const;
  
#ifndef GTKMM_DISABLE_DEPRECATED

  /** Get the icon name being used for this icon.
   * 
   * When an icon looked up in the icon theme was not available, the
   * icon theme may use fallback icons - either those specified to
   * Gtk::IconTheme::lookup_icon() or the always-available
   * "image-missing". The icon chosen is returned by this function.
   * 
   * If the icon was created without an icon theme, this function
   * returns <tt>nullptr</tt>.
   * 
   * Deprecated: 4.20
   * 
   * @deprecated 4.20: There is no replacement.
   * 
   * @return The themed icon-name for the
   * icon, or <tt>nullptr</tt> if its not a themed icon.
   */
  Glib::ustring get_icon_name() const;
#endif // GTKMM_DISABLE_DEPRECATED


#ifndef GTKMM_DISABLE_DEPRECATED

  /** Checks if the icon is symbolic or not.
   * 
   * This currently uses only the file name and not the file contents
   * for determining this. This behaviour may change in the future.
   * 
   * Deprecated: 4.20
   * 
   * @deprecated 4.20: There is no replacement.
   * 
   * @return True if the icon is symbolic, false otherwise.
   */
  bool is_symbolic() const;
#endif // GTKMM_DISABLE_DEPRECATED


  /** The file representing the icon, if any.
   *
   * @return A PropertyProxy_ReadOnly that allows you to get the value of the property,
   * or receive notification when the value of the property changes.
   */
  Glib::PropertyProxy_ReadOnly< Glib::RefPtr<Gio::File> > property_file() const;


#ifndef GTKMM_DISABLE_DEPRECATED

/** The icon name that was chosen during lookup.
   * 
   * Deprecated: 4.20
   * 
   * @deprecated 4.20: There is no replacement.
   *
   * Default value: ""
   *
   * @return A PropertyProxy_ReadOnly that allows you to get the value of the property,
   * or receive notification when the value of the property changes.
   */
  Glib::PropertyProxy_ReadOnly< Glib::ustring > property_icon_name() const;


#endif // GTKMM_DISABLE_DEPRECATED

  
#ifndef GTKMM_DISABLE_DEPRECATED

/** Whether the icon is symbolic or not.
   * 
   * Deprecated: 4.20
   * 
   * @deprecated 4.20: There is no replacement.
   *
   * Default value: <tt>false</tt>
   *
   * @return A PropertyProxy that allows you to get or set the value of the property,
   * or receive notification when the value of the property changes.
   */
  Glib::PropertyProxy< bool > property_is_symbolic() ;

/** Whether the icon is symbolic or not.
   * 
   * Deprecated: 4.20
   * 
   * @deprecated 4.20: There is no replacement.
   *
   * Default value: <tt>false</tt>
   *
   * @return A PropertyProxy_ReadOnly that allows you to get the value of the property,
   * or receive notification when the value of the property changes.
   */
  Glib::PropertyProxy_ReadOnly< bool > property_is_symbolic() const;

#endif // GTKMM_DISABLE_DEPRECATED


public:

public:
  //C++ methods used to invoke GTK+ virtual functions:

protected:
  //GTK+ Virtual Functions (override these to change behaviour):

  //Default Signal Handlers::


};

} // namespace Gtk


namespace Glib
{
  /** A Glib::wrap() method for this object.
   *
   * @param object The C instance.
   * @param take_copy False if the result should take ownership of the C instance. True if it should take a new copy or ref.
   * @result A C++ instance that wraps this C instance.
   *
   * @relates Gtk::IconPaintable
   */
  GTKMM_API
  Glib::RefPtr<Gtk::IconPaintable> wrap(GtkIconPaintable* object, bool take_copy = false);
}


#endif /* _GTKMM_ICONPAINTABLE_H */

